using UnityEngine;
using UnityEngine.UI;
using UnityEngine.Events;

using SDX.Payload;


public class SDXEntityClass : SDX.Payload.ModScript
{
	
	public override void OnGameStarted()
	{
		
	}
	
	public override void OnEModelBaseCreateModel(object modelBase, Transform meshTransform, object entityClassObj)
	{
		EntityClass entClass = entityClassObj as EntityClass;
		
		if(entClass.Properties.Values.ContainsKey("MeshMaterial"))
		{
			string matVal = entClass.Properties.Values["MeshMaterial"];
			ModEngine.Log("Found MeshMaterial: " + matVal);
			
			Material mat = ResourceWrapper.Load(matVal, typeof(Material)) as Material;
			if(mat == null)
			{
				ModEngine.Log("Could not find mat!");
				return;
			}
			
			ModEngine.Log("Found mat!");
			
			SkinnedMeshRenderer[] renderers = meshTransform.GetComponentsInChildren<SkinnedMeshRenderer>();
			if(renderers == null)
			{
				ModEngine.Log("Could not find renderer!");
				return;
			}
			
			ModEngine.Log("Set material!");
			foreach(SkinnedMeshRenderer renderer in renderers)
			{
				renderer.material = mat;
			}
		}
		
		if(entClass.Properties.Values.ContainsKey("MeshTexture"))
		{
			string textureVal = entClass.Properties.Values["MeshTexture"];
			ModEngine.Log("Found MeshTexture: " + textureVal);
			
			Texture2D tex = ResourceWrapper.Load(textureVal, typeof(Texture2D)) as Texture2D;
			if(tex == null)
			{
				ModEngine.Log("Could not find texture!");
				return;
			}
			
			ModEngine.Log("Found texture!");
			
			SkinnedMeshRenderer[] renderers = meshTransform.GetComponentsInChildren<SkinnedMeshRenderer>();
			if(renderers == null)
			{
				ModEngine.Log("Could not find renderer!");
				return;
			}
			
			
			ModEngine.Log("Set material texture!");
			foreach(SkinnedMeshRenderer renderer in renderers)
			{
				ModEngine.Log(renderer.material.name + ", " + renderer.material.shader.name);
				renderer.material.mainTexture = tex;
			}
		}
		
		if(entClass.Properties.Values.ContainsKey("MeshScale"))
		{
			string meshScaleStr = entClass.Properties.Values["MeshScale"];
			string[] parts = meshScaleStr.Split(',');
			
			float minScale = 1;
			float maxScale = 1;
			
			if(parts.Length == 1)
			{
				maxScale = minScale = float.Parse(parts[0]);
			}
			else if(parts.Length == 2)
			{
				minScale = float.Parse(parts[0]);
				maxScale = float.Parse(parts[1]);
			}
			
			float meshScale = Random.Range(minScale, maxScale);
			meshTransform.parent.localScale = new Vector3(meshScale,meshScale,meshScale);
		}
	}
	
}
